@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#     Copyright 2021, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -42,15 +42,24 @@ import shutil
 import subprocess
 import time
 
+from nuitka.tools.Basics import addPYTHONPATH
 from nuitka.tools.testing.Common import (
+    getPythonSysPath,
     getTempDir,
     my_print,
     setup,
     test_logger,
+    withPythonPathChange,
 )
 from nuitka.utils.Execution import wrapCommandForDebuggerForSubprocess
-from nuitka.utils.FileOperations import copyTree, listDir, removeDirectory
+from nuitka.utils.FileOperations import (
+    copyTree,
+    deleteFile,
+    listDir,
+    removeDirectory,
+)
 from nuitka.utils.Importing import getSharedLibrarySuffix
+from nuitka.Version import getCommercialVersion
 
 nuitka_main_path = os.path.join("..", "..", "bin", "nuitka")
 
@@ -58,7 +67,7 @@ tmp_dir = getTempDir()
 
 # Cannot detect this more automatic, so we need to list them, avoiding
 # the ones not needed.
-PACKAGE_LIST = (
+PACKAGE_LIST = [
     "nuitka",
     "nuitka/nodes",
     "nuitka/specs",
@@ -67,9 +76,9 @@ PACKAGE_LIST = (
     "nuitka/importing",
     "nuitka/build",
     "nuitka/freezer",
-    "nuitka/codegen",
-    "nuitka/codegen/templates",
-    "nuitka/codegen/c_types",
+    "nuitka/code_generation",
+    "nuitka/code_generation/templates",
+    "nuitka/code_generation/c_types",
     "nuitka/optimizations",
     "nuitka/finalizations",
     "nuitka/plugins",
@@ -79,7 +88,10 @@ PACKAGE_LIST = (
     "nuitka/constants",
     "nuitka/containers",
     "nuitka/utils",
-)
+]
+
+if not getCommercialVersion():
+    PACKAGE_LIST.remove("nuitka/plugins/commercial")
 
 exe_suffix = ".exe" if os.name == "nt" else ".bin"
 
@@ -200,7 +212,7 @@ def executePASS1():
         os.mkdir(target_dir)
 
         for path, filename in listDir(target_dir):
-            if filename.endswith(".so"):
+            if filename.endswith((".so", ".dylib")):
                 os.unlink(path)
 
         for path, filename in listDir(source_dir):
@@ -218,7 +230,6 @@ def executePASS1():
                     nuitka_main_path,
                     "--module",
                     "--nofollow-imports",
-                    "--plugin-enable=pylint-warnings",
                     "--output-dir=%s" % target_dir,
                     "--no-pyi-file",
                     path,
@@ -244,7 +255,7 @@ def executePASS1():
         "--nofollow-imports",
         "--plugin-enable=pylint-warnings",
         "--output-dir=.",
-        "--python-flag=-S",
+        "--python-flag=no_site",
         "nuitka-runner.py",
     ]
     command += os.environ.get("NUITKA_EXTRA_OPTIONS", "").split()
@@ -265,9 +276,9 @@ def executePASS1():
     # Copy required data files.
     for filename in (
         "nuitka/build/Backend.scons",
-        "nuitka/plugins/standard/anti-bloat.yml",
-        "nuitka/plugins/standard/implicit-imports.yml",
-        "nuitka/plugins/standard/data-files.yml",
+        "nuitka/plugins/standard/standard.nuitka-package.config.yml",
+        "nuitka/plugins/standard/stdlib3.nuitka-package.config.yml",
+        "nuitka/plugins/standard/stdlib2.nuitka-package.config.yml",
     ):
         shutil.copyfile(
             os.path.join(base_dir, filename),
@@ -275,8 +286,8 @@ def executePASS1():
         )
 
     copyTree(
-        os.path.join(base_dir, "nuitka", "codegen", "templates_c"),
-        os.path.join("nuitka", "codegen", "templates_c"),
+        os.path.join(base_dir, "nuitka", "code_generation", "templates_c"),
+        os.path.join("nuitka", "code_generation", "templates_c"),
     )
 
     copyTree(
@@ -332,6 +343,7 @@ def compileAndCompareWith(nuitka, pass_number):
                     "--plugin-enable=pylint-warnings",
                     "--output-dir=%s" % tmp_dir,
                     "--no-pyi-file",
+                    "--nofollow-imports",
                     path,
                 ]
                 command += os.environ.get("NUITKA_EXTRA_OPTIONS", "").split()
@@ -355,30 +367,30 @@ def compileAndCompareWith(nuitka, pass_number):
 
                 shutil.rmtree(target_dir)
 
-                target_filename = filename.replace(
-                    ".py", getSharedLibrarySuffix(preferred=True)
-                )
+                for preferred in (True, False):
+                    target_filename = filename.replace(
+                        ".py", getSharedLibrarySuffix(preferred=preferred)
+                    )
 
-                os.unlink(os.path.join(tmp_dir, target_filename))
+                    deleteFile(
+                        path=os.path.join(tmp_dir, target_filename), must_exist=False
+                    )
 
 
 def executePASS2():
     test_logger.info(
-        "PASS 2: Compiling from compiler running from entry .exe and many .so files."
+        "PASS 2: Compiling from compiler running from entry '.exe' and many extension files."
     )
 
-    # Windows will load the compiled modules (pyd) only from PYTHONPATH, so we
-    # have to add it.
-    if os.name == "nt":
-        os.environ["PYTHONPATH"] = ":".join(PACKAGE_LIST)
+    with withPythonPathChange(getPythonSysPath()):
+        # Windows will load the compiled modules (pyd) only from PYTHONPATH, so we
+        # have to add it.
+        if os.name == "nt":
+            addPYTHONPATH(PACKAGE_LIST)
 
-    compileAndCompareWith(
-        nuitka=os.path.join(".", "nuitka" + exe_suffix), pass_number=2
-    )
-
-    # Undo the damage from above.
-    if os.name == "nt":
-        del os.environ["PYTHONPATH"]
+        compileAndCompareWith(
+            nuitka=os.path.join(".", "nuitka" + exe_suffix), pass_number=2
+        )
 
     test_logger.info("OK.")
 
@@ -409,7 +421,6 @@ def executePASS3():
         "--output-dir=%s" % tmp_dir,
         "--python-flag=-S",
         "--follow-imports",
-        #        "--include-package=nuitka.plugins",
     ]
 
     my_print("Command: ", " ".join(command))
@@ -428,13 +439,21 @@ def executePASS4():
 
     exe_path = os.path.join(tmp_dir, "nuitka" + exe_suffix)
 
-    compileAndCompareWith(exe_path, pass_number=4)
+    with withPythonPathChange(getPythonSysPath()):
+        # Windows will load the compiled modules (pyd) only from PYTHONPATH, so we
+        # have to add it.
+        if os.name == "nt":
+            addPYTHONPATH(PACKAGE_LIST)
+
+        compileAndCompareWith(exe_path, pass_number=4)
 
     test_logger.info("OK.")
 
 
 def executePASS5():
-    my_print("PASS 5: Compiling the compiler 'nuitka' package to single '.so' file.")
+    my_print(
+        "PASS 5: Compiling the compiler 'nuitka' package to single extension module."
+    )
 
     path = os.path.join("..", "..", "nuitka")
 
@@ -447,6 +466,7 @@ def executePASS5():
         "--nofollow-import-to=nuitka.build.inline_copy",
         "--nofollow-import-to=nuitka.build.include",
         "--nofollow-import-to=nuitka.build.static_src",
+        "--nofollow-import-to=nuitka.tools",
         "--module",
         path,
     ]
@@ -456,7 +476,11 @@ def executePASS5():
     if result != 0:
         sys.exit(result)
 
-    os.unlink(os.path.join(tmp_dir, "nuitka" + getSharedLibrarySuffix(preferred=True)))
+    for preferred in True, False:
+        candidate = "nuitka" + getSharedLibrarySuffix(preferred=preferred)
+
+        deleteFile(candidate, must_exist=False)
+
     os.unlink(os.path.join(tmp_dir, "nuitka.pyi"))
     shutil.rmtree(os.path.join(tmp_dir, "nuitka.build"))
 
